@@ -40,7 +40,7 @@ __author__ = "Rob Knight"
 __copyright__ = "Copyright 2011, The QIIME Project" 
 __credits__ = ["Rob Knight","William Walters"] #remember to add yourself
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "William Walters"
 __email__ = "rob@spot.colorado.edu","william.a.walters@colorado.edu"
 __status__ = "Release"
@@ -72,7 +72,7 @@ STANDARD_FIELD_TYPES = {SAMPLE_ID_KEY:'uid', BARCODE_KEY:'uid', \
 # Header category most restrictive
 ALLOWED_CHARS_HEADER = '_' + digits + letters
 # Metadata should be fairly restricted as well
-EXTRA_DESC_CHARS = "+-%."
+EXTRA_DESC_CHARS = "+-%./ :,;"
 #EXTRA_COMMENT_CHARS =  ''
 ALLOWED_DESC_CHARS = ALLOWED_CHARS_HEADER + EXTRA_DESC_CHARS
 # Comment line(s) following header should not be used for parsing data
@@ -156,7 +156,7 @@ class CharFilter(object):
         return self(input), self.errMsg(input)
         
 header_filter = CharFilter(ALLOWED_CHARS_HEADER, "Header Filter", 
-    default_char='#')
+    default_char='')
 descr_filter = CharFilter(ALLOWED_DESC_CHARS, "Description Filter", 
     default_char='_')
 subcat_filter = CharFilter(ALLOWED_SUBCAT_CHARS, "Subcat Filter", 
@@ -465,7 +465,7 @@ def bad_char_in_header(fields, raw_data=None, added_demultiplex_field=None):
     filtered_fields=[]
     for f in fields:
         filtered, bad = header_filter.resultAndError(f)
-        if bad:
+        if bad and f != "#SampleID":
             bad_chars.append([f, bad])
         filtered_fields.append(filtered)
     if bad_chars:
@@ -920,7 +920,6 @@ STANDARD_FILENAME_CHECKS = [(filename_has_space, 'error')]
     (descr_filter.resultAndError, 'warning')] '''
 STANDARD_SAMPLE_DESCRIPTION_CHECKS = [
     (check_missing_descriptions, 'warning'),
-    (check_duplicate_descriptions, 'warning'),
     (check_duplicate_sample_ids, 'warning'),
     (check_description_chars, 'warning'),
     ]
