@@ -12,7 +12,7 @@ __author__ = "Rob Knight"
 __copyright__ = "Copyright 2011, The QIIME Project" 
 __credits__ = ["Rob Knight", "Antonio Gonzalez Pena"] #remember to add yourself if you make changes
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Tony Walters"
 __email__ = "William.A.Walters@colorado.edu"
 __status__ = "Release"
@@ -77,44 +77,57 @@ def filter_line(line, good_fields, min_count=None, outfile=stdout):
     else:
         num_slice = slice(1,None)
     fields = map(strip, line.split('\t'))
+    
     result = [fields[i] for i in good_fields]
     if min_count is not None:
         if array(map(float, result[num_slice]), dtype=float).sum() < min_count:
             return
     outfile.write('\t'.join([fields[i] for i in good_fields])+'\n')
 
-def filter_map(map_data, map_header, good_sample_ids):
+def filter_map(map_data, map_header, good_sample_ids, include_repeat_cols=False, column_rename_ids=None):
     """Filters map according to several criteria.
 
     - keep only sample ids in good_sample_ids
     - drop cols that are different in every sample (except id)
     - drop cols that are the same in every sample
     """
-    d = array(map_data) #note, will contain row headers
-    first_col = list(d[:,0])    #assume contains sample ids
-    good_row_indices = [first_col.index(i) for i in good_sample_ids 
-        if i in first_col]
-    d = d[good_row_indices]
-    cols = d.T
+    # keeping samples
+    to_keep = []
+    to_keep.extend([i for i in map_data if i[0] in good_sample_ids])
     
-    # Determine the good column indices
-    # always include the sample id col
-    good_col_indices = [0]
-    # for all cols between the first and last, 
-    # include the col if there are more than
-    # 2 states, and less than 1 state per sample ID 
-    good_col_indices +=\
-     [i+1 for (i, col) in enumerate(cols[1:-1]) 
-      if 2 <= len(set(col)) < (len(col))]
-    # always include the description col
-    good_col_indices += [len(cols)-1]
-    h = [map_header[i] for i in good_col_indices]
-    d = d[:,good_col_indices]
+    # keeping columns
+    headers = []
+    to_keep = zip(*to_keep)
+    headers.append(map_header[0])
+    result = [to_keep[0]]
     
-    return h, map(list, d)
+    if column_rename_ids:
+        # reduce in 1 as we are not using the first colum (SampleID)
+        column_rename_ids = column_rename_ids-1
+        for i,l in enumerate(to_keep[1:-1]):
+            if i==column_rename_ids:
+                if len(set(l))!=len(result[0]):
+                     raise ValueError, "The column to rename the samples is not unique."
+                result.append(result[0])
+                result[0] = l
+                headers.append('SampleID_was_' + map_header[i+1])
+            elif include_repeat_cols or len(set(l))>1:
+                headers.append(map_header[i+1])
+                result.append(l)
+    else:
+        for i,l in enumerate(to_keep[1:-1]):
+            if include_repeat_cols or len(set(l))>1:
+                headers.append(map_header[i+1])
+                result.append(l)
+    headers.append(map_header[-1])
+    result.append(to_keep[-1])
+    
+    result = map(list,zip(*result))
+    
+    return headers, result
 
 def filter_otus_and_map(map_infile, otu_infile, map_outfile, otu_outfile, 
-    valid_states_str, num_seqs_per_otu):
+    valid_states_str, num_seqs_per_otu, include_repeat_cols=False, column_rename_ids=None):
     """Filters OTU and map files according to specified criteria."""
     map_data, map_header, map_comments = parse_mapping_file(map_infile)
     map_infile.close()
@@ -122,23 +135,46 @@ def filter_otus_and_map(map_infile, otu_infile, map_outfile, otu_outfile,
     sample_ids = get_sample_ids(map_data, map_header, valid_states)
 
     # write out the filtered mapping file
-    out_headers, out_data = filter_map(map_data, map_header, sample_ids)
+    out_headers, out_data = filter_map(map_data, map_header, sample_ids, \
+                                       include_repeat_cols=include_repeat_cols,\
+                                       column_rename_ids=column_rename_ids)
     header_line = '#' + '\t'.join(out_headers)
     map_outfile.write('\n'.join([header_line] + map('\t'.join, out_data)))
     if not isinstance(map_outfile, StringIO):
         map_outfile.close()
-
+    
     # write out the filtered OTU file
     for line in otu_infile:
         if line.startswith('#OTU ID'):
-            fields = map(strip, line.split('\t'))
             cols = find_good_cols(line, sample_ids)
-            filter_line(line, cols, min_count=None, outfile=otu_outfile)
+            if column_rename_ids:
+                map_ref = {}
+                for m in map_data:
+                    map_ref[m[0]] = m[column_rename_ids]
+                fields = line.strip().split('\t')
+                
+                new_line = []
+                for f in fields:
+                    if f in map_ref:
+                        new_line.append(map_ref[f])
+                    else:
+                        new_line.append(f)
+                
+                line = '\t'.join(new_line)
+            try:
+                filter_line(line, cols, min_count=None, outfile=otu_outfile)
+            except UnboundLocalError:
+                raise ValueError, "Error: Your OTU table doesn't have a valid header."
         elif line.startswith('#'):
             otu_outfile.write(line)
-        else:
-            filter_line(line, cols, min_count=num_seqs_per_otu, 
-                outfile=otu_outfile)
+        elif len(line)>1:
+            try:
+                filter_line(line, cols, min_count=num_seqs_per_otu, 
+                    outfile=otu_outfile)
+            except UnboundLocalError:
+                raise ValueError, "Error: Your OTU table doesn't have a valid header."
+            
+                
     if not isinstance(otu_outfile, StringIO):
         otu_outfile.close()
 
