@@ -6,7 +6,7 @@ __credits__ = ["Rob Knight", "Justin Kuczynski","Jeremy Widmann", \
         "Antonio Gonzalez Pena", "Daniel McDonald"] 
 #remember to add yourself if you make changes
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 __status__ = "Release"
@@ -15,6 +15,7 @@ import numpy
 from numpy import isnan, log10, median
 from StringIO import StringIO
 from cogent import Sequence
+from re import compile, sub
 
 """Contains formatters for the files we expect to encounter in 454 workflow.
 
@@ -91,8 +92,22 @@ def format_summarize_taxa(summary, header, delimiter=';'):
 
         yield "%s\n" % '\t'.join(line)
  
-def write_summarize_taxa(summary, header, output_fp, delimiter=';'):
+def write_summarize_taxa(summary, header, output_fp, delimiter=';', transposed_output=False):
     """ """
+    # Fixing headers
+    pattern = compile('\W')
+    header = [sub(pattern, '.', label) for label in header]
+
+    if transposed_output:
+         # transposing the summary
+         summary = [[r[col] for r in summary] for col in range(len(summary[0]))]
+         # adding the first column into the new summary matrix
+         for i in range(1,len(summary)):
+             summary[i] = [([header[i]])] + summary[i]
+         # replacing header and trimming summary
+         header = ['SampleID'] + [delimiter.join(taxon) for taxon in summary[0]]
+         summary = summary[1:]
+    
     of = open(output_fp,'w')
     for line in format_summarize_taxa(summary, header, delimiter):
         of.write(line)
@@ -262,11 +277,12 @@ def format_nmds_coords(samples, points, stress):
     """
     result = []
     col_headers = ["NMDS"+str(aa) for aa in range(1,points.shape[1]+1)]
-    result.append('sample\t' + '\t'.join(col_headers) )
+    result.append('samples\t' + '\t'.join(col_headers) )
     for name, row in zip(samples, points):
         result.append('\t'.join([name] + map(str, row)))
     result.append('')
-    result.append('stress\t' + str(stress))
+    result.append('stress\t' + str(stress) + '\t' + '0\t'*(len(col_headers)-2) + '0')
+    result.append('% variation explained\t' + '0\t'*(len(col_headers)))
     return '\n'.join(result)    
     
 
@@ -527,6 +543,14 @@ def illumina_data_to_fastq(record_data,number_of_bases=None):
     """
     seq_index = 8
     qual_index = 9
+    pass_filter_index = 10
+    
+    try:
+        pass_filter = int(record_data[pass_filter_index])
+    except IndexError:
+        pass_filter = 2
+        
+    
     if number_of_bases == None:
         seq = record_data[seq_index].replace('.','N')
         qual = record_data[qual_index]
@@ -545,8 +569,6 @@ def illumina_data_to_fastq(record_data,number_of_bases=None):
       record_data[6],
       record_data[7])
     
-    return '@%s\n%s\n+\n%s' % (header,
-      seq,
-      qual)
+    return '@%s\n%s\n+\n%s' % (header,seq,qual), pass_filter
 
 
