@@ -5,7 +5,7 @@ __author__ = "Justin Kuczynski"
 __copyright__ = "Copyright 2011, The QIIME Project" 
 __credits__ = ["Justin Kuczynski"]
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Justin Kuczynski"
 __email__ = "justinak@gmail.com"
 __status__ = "Release"
@@ -53,7 +53,9 @@ TO DOs:
 def get_invalid_golay_barcodes(seqs):
     result = []
     for e in seqs:
-        if decode(e)[1] > 0:
+        if len(e) != 12:
+            result.append(e)
+        elif decode(e)[1] > 0:
             result.append(e)
     return result
 
