@@ -6,7 +6,7 @@ __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Jesse Stombaugh", "Rob Knight", "Micah Hamady", "Dan Knights",\
 "Antonio Gonzalez Pena"] #remember to add yourself
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Jesse Stombaugh"
 __email__ = "jesse.stombaugh@colorado.edu"
 __status__ = "Release"
@@ -16,7 +16,8 @@ from cogent.util.misc import flatten
 from qiime.parse import parse_coords,group_by_field,parse_mapping_file
 from qiime.colors import get_group_colors, color_groups, make_color_dict, combine_map_label_cols, process_colorby, linear_gradient, iter_color_groups, get_map, kinemage_colors
 from qiime.sort import natsort
-from numpy import array, shape, apply_along_axis, dot, delete, vstack, sqrt
+from numpy import array, shape, apply_along_axis, dot, delete, vstack, sqrt, average, isnan, nan
+from numpy.linalg import norm
 import numpy as np
 import os
 from random import choice
@@ -25,7 +26,8 @@ from time import strftime
 from biplots import make_mage_taxa
 from qiime.util import load_pcoa_files, summarize_pcoas, MissingFileError
 from qiime.format import format_coords
-
+from cogent.maths.stats.test import ANOVA_one_way
+from cogent.maths.stats.util import Numbers
 
 '''
 xdata_colors = {
@@ -77,7 +79,8 @@ def make_3d_plots(coord_header, coords, pct_var, mapping, prefs, \
                     edges=None, coords_low=None, coords_high=None, \
                     ellipsoid_prefs=None, \
                     user_supplied_edges=False, ball_scale=1.0, \
-                    arrow_colors={'line_color': 'white', 'head_color': 'red'}):
+                    arrow_colors={'line_color': 'white', 'head_color': 'red'},
+                    add_vectors=None):
     """Makes 3d plots given coords, mapping file, and prefs.
     
     Added quick-and-dirty hack for gradient coloring of columns, should
@@ -101,7 +104,36 @@ def make_3d_plots(coord_header, coords, pct_var, mapping, prefs, \
     #Sort by the column name first
     groups_and_colors=iter_color_groups(mapping,prefs)
     groups_and_colors=list(groups_and_colors)
-
+    
+    # processing the vectors
+    if add_vectors:
+        # validating the values in add_vectors
+        for label in add_vectors['vectors']:
+            if label not in mapping[0]:
+                raise ValueError, "Couldn't find name %s in headers: %s" \
+                    % (label, mapping[0])
+                    
+        # getting the index of the columns in the mapping file
+        ind_group = mapping[0].index(add_vectors['vectors'][0])
+        if len(add_vectors['vectors'])>=2:
+            ind_sort = mapping[0].index(add_vectors['vectors'][1])
+        else: 
+            ind_sort = 0
+        
+        # creating groups 
+        groups = {}
+        for l in mapping[1:]:
+            if l[0] not in coord_header:
+                continue
+            if l[ind_group] not in groups:
+                groups[l[ind_group]] = [(l[ind_sort],l[0])]
+            else:
+                groups[l[ind_group]].append((l[ind_sort],l[0]))
+        for g in groups:
+            groups[g] = natsort(groups[g])
+        add_vectors['vectors'] = groups
+    
+    
     for i in range(len(groups_and_colors)):  
         #Write to kinemage file using the groups, colors and coords 
         labelname=groups_and_colors[i][0]
@@ -117,7 +149,8 @@ def make_3d_plots(coord_header, coords, pct_var, mapping, prefs, \
             coords_low=coords_low, coords_high=coords_high, \
             ellipsoid_prefs=ellipsoid_prefs, \
             user_supplied_edges=user_supplied_edges, \
-            ball_scale=ball_scale, arrow_colors=arrow_colors))
+            ball_scale=ball_scale, arrow_colors=arrow_colors, \
+            add_vectors=add_vectors))
         result.extend(make_mage_output(groups, colors, coord_header, coords, \
             pct_var,background_color,label_color,data_colors, \
             taxa, custom_axes,name=labelname, \
@@ -125,8 +158,9 @@ def make_3d_plots(coord_header, coords, pct_var, mapping, prefs, \
             coords_low=coords_low, coords_high=coords_high, \
             ellipsoid_prefs=ellipsoid_prefs, \
             user_supplied_edges=user_supplied_edges, \
-            ball_scale=ball_scale, arrow_colors=arrow_colors))
-
+            ball_scale=ball_scale, arrow_colors=arrow_colors, \
+            add_vectors=add_vectors))
+                
     return result
 
 def scale_pc_data_matrix(coords, pct_var):
@@ -147,10 +181,11 @@ def make_mage_output(groups, colors, coord_header, coords, pct_var, \
                      coord_scale=1.05, edges=None, coords_low=None, \
                      coords_high=None, ellipsoid_prefs=None,
                      user_supplied_edges=False, ball_scale=1.0, \
-                     arrow_colors={'line_color': 'white', 'head_color': 'red'}):
+                     arrow_colors={'line_color': 'white', 'head_color': 'red'},
+                     add_vectors=None):
     """Convert groups, colors, coords and percent var into mage format"""
     result = []
-
+    
     #Scale the coords and generate header labels
     if scaled:
         scalars = pct_var
@@ -171,7 +206,7 @@ def make_mage_output(groups, colors, coord_header, coords, pct_var, \
         radius = float(auto_radius(coords))*float(ball_scale)
     else:
         radius = float(radius)*float(ball_scale)
-        
+      
     maxes = coords.max(0)[:num_coords]
     mins = coords.min(0)[:num_coords]
     pct_var = pct_var[:num_coords]    #scale from fraction
@@ -189,7 +224,7 @@ def make_mage_output(groups, colors, coord_header, coords, pct_var, \
 
     #Write the header information
     result.append('@kinemage {%s}' % (name+header_suffix))
-    result.append('@dimension '+' '.join(['{%s}'%(name) for name in axis_names]))
+    result.append('@dimension '+' '.join(['{%s}'%(aname) for aname in axis_names]))
     result.append('@dimminmax '+ ' '.join(map(str, min_maxes)))
     result.append('@master {points}')
     result.append('@master {labels}')
@@ -200,7 +235,7 @@ def make_mage_output(groups, colors, coord_header, coords, pct_var, \
         result.append('@master {taxa_points}')
         result.append('@master {taxa_labels}')
 
-    for name, color in sorted(data_colors.items()):
+    for cname, color in sorted(data_colors.items()):
         result.append(color.toMage())
 
     if background_color=='white':
@@ -218,7 +253,7 @@ def make_mage_output(groups, colors, coord_header, coords, pct_var, \
     for group_name in natsort(groups):
         ids = groups[group_name]
         result.append('@group {%s (n=%s)} collapsible' % (group_name, len(ids)))
-
+        
         color = colors[group_name]
         coord_lines = []
         for id_ in sorted(ids):
@@ -240,6 +275,22 @@ master={points} nobutton' % (color, radius, alpha, num_coords))
         result.append('@labellist color=%s radius=%s alpha=%s dimension=%s \
 master={labels} nobutton' % (color, radius, alpha, num_coords))
         result.append('\n'.join(coord_lines))
+        
+        # Write vectors if requested
+        if add_vectors:
+            result += make_vectors_output(coord_dict, add_vectors, num_coords, color, \
+                                          ids)
+            if not scaled and add_vectors['rms_path'] and add_vectors['rms_algorithm']:
+               vector_result = make_subgroup_rms(coord_dict, add_vectors['eigvals'], \
+                                                 ids, add_vectors['rms_algorithm'], \
+                                                 custom_axes)
+               if not isnan(vector_result['rms']):
+                   if name not in add_vectors['rms_output']:
+                       add_vectors['rms_output'][name] = {}
+                   if group_name not in add_vectors['rms_output'][name]:
+                       add_vectors['rms_output'][name][group_name] = {}
+                   add_vectors['rms_output'][name][group_name]['rms_vector'] = vector_result['vector']
+                   add_vectors['rms_output'][name][group_name]['rms_result'] = vector_result['rms']
 
     if not taxa is None:
         result += make_mage_taxa(taxa, num_coords, pct_var,
@@ -285,8 +336,152 @@ master={labels} nobutton' % (color, radius, alpha, num_coords))
         result += make_edges_output(coord_dict, edges, num_coords, label_color,
                                     arrow_colors=arrow_colors,
                                     user_supplied_edges=user_supplied_edges)
+    
     return result
 
+
+def make_subgroup_rms(coord_dict, eigvals, ids, method='avg', custom_axes=None):
+    """Creates the rms value, vector, of a subgroup (ids) of coord_dict
+    
+       Params: 
+        coord_dict: a dict of (sampleID, coords), where coords is a numpy array (row)
+        eigvals: the eigvals of the coords
+        ids: the list of ids that should be use to caclulate the rms from coord_dict
+        custom_axes: the list of custom axis used in other methods
+        
+       Returns:
+        a dict with 2 members: 'vector', the vector representing from which 
+        the RMS value was calculated; and 'rms' the resulting RMS from the 
+        vector.
+    """
+    result = {}
+    
+    # We multiply the cood values with the value of the eigvals represented
+    if custom_axes:
+        vectors = [coord_dict[id][1:]*eigvals for id in ids if id in coord_dict]
+    else:
+        vectors = [coord_dict[id]*eigvals for id in ids if id in coord_dict]
+    
+    if method=='avg':
+       center = average(vectors,axis=0)
+       if len(ids)==1:
+           result['vector'] = norm(center)
+           result['rms'] = result['vector']
+       else:
+           result['vector'] = [norm(i) for i in vectors-center]
+           result['rms'] = average(result['vector'])
+    elif method=='trajectory':
+       if len(ids)==1:
+           result['vector'] = norm(vectors)
+           result['rms'] = result['vector']
+       else:
+           result['vector'] = [norm(vectors[i-1]-vectors[i])  for i in range(len(vectors)-1)] 
+           result['rms']=norm(result['vector'])
+    elif method==None:
+       result['rms']=nan
+    else:
+       raise ValueError, 'The method "%s" for RMS does not exist' % method
+       
+    return result
+
+
+def run_ANOVA_trajetories(groups):
+    """Run ANOVA on trajectories categories
+
+       Params: 
+        groups, a dict of {trajectory_id: values}, where trajectory_id is
+        each of the categories to test, values is a numpy array with the edges of 
+        that trajectory
+        
+       Returns:
+        look at otu_category_significance.py -> run_single_ANOVA
+        
+        This was taken from qiime/otu_category_significance.py:run_single_ANOVA
+    """
+    values = []
+    for trajectory in groups:
+        values.append(Numbers(groups[trajectory]))
+            
+    # This is copied from otu_category_significance.py
+    try:
+        dfn, dfd, F, between_MS, within_MS, group_means, prob = ANOVA_one_way(values)
+        return group_means, prob
+    except ValueError:
+        #set the p-value to 'diff' if the variances are 0.0 (within rounding 
+        #error) and the means are not all the same. If the means are all
+        #the same and the variances are 0.0, set the p-value to 1
+        group_means = []
+        group_variances = []
+        for i in values:
+            group_means.append(i.Mean)
+            group_variances.append(i.Variance)
+        group_means = set(group_means)
+        if sum(group_variances) < 1e-21 and len(group_means) > 1:
+            prob = 0.0
+        else:
+            prob = 1.0
+        return group_means, prob
+        
+def make_vectors_output(coord_dict, add_vectors, num_coords, color, ids):
+    """Creates make output to display vectors (as a kinemage vectorlist).
+
+       Params:
+        coord_dict, a dict of (sampleID, coords), where coords is a numpy 
+        array edges, a dictionary of pairs of samples where 
+        ['label': [('order': sampleID) ...]
+        num_coords, the number of included dimensions in the PCoA plot 
+        color, the color of this batch of vectors, 
+        ids the list of ids that are in this batch and where the first member 
+        of the groups id a should be a member of.
+        
+       Returns:
+        result, a list of strings containing a kinemage vectorlist
+    """
+    # default parameters
+    which_set = 0
+    tip_fraction=0.5
+    arrow_colors = {'line_color': color, 'head_color': color}
+    
+    # header for section in kin file
+    result = []
+    result.append('@vectorlist {trace} dimension=%s on' % (num_coords))
+    
+    # selecting the edges to draw in this batch
+    edges = []
+    for k, v in add_vectors['vectors'].iteritems():
+        edges = edges + [(v[i][1],v[i+1][1]) for i in range(len(v[:-1])) if v[i][1] in ids]
+    
+    # creating "vectors"
+    for edge in edges:
+        id_fr, id_to = edge
+        # extract the coords of each vertex
+        pt_fr = coord_dict[id_fr][:num_coords]
+        pt_to = coord_dict[id_to][:num_coords]
+
+        # different tip color for each destination coords file
+        #tip_color = kinemage_colors[which_set % len(kinemage_colors)]
+        # plot a color 'tip' on the line (certain % of line length)
+        # this gets the coords of the beginning of the 'tip'
+        diffs = (pt_to-pt_fr) * (1-tip_fraction)
+        middles = pt_fr + diffs
+        # add a default-color line segment
+        
+        # modified to use user defined
+        tip_color = arrow_colors['head_color']
+        label_color = arrow_colors['line_color']
+        
+        result.append('%s %s' % \
+                          (' '.join(map(str, pt_fr)),label_color))
+        result.append('%s %s P' % \
+                          (' '.join(map(str, middles)),label_color))
+        # add the tip-colored line segment
+        result.append('%s %s' % \
+                          (' '.join(map(str, middles)), tip_color))
+        result.append('%s %s P' % \
+                          (' '.join(map(str, pt_to)), tip_color))            
+    return result
+
+
 def make_edges_output(coord_dict, edges, num_coords, label_color, arrow_colors, 
                       tip_fraction=0.4,user_supplied_edges=False):
     """Creates make output to display edges (as a kinemage vectorlist).
@@ -434,8 +629,6 @@ def translate_faces(center, faces):
             faces[i][j] = (point[0]+center[0], point[1]+center[1], point[2]+center[2])
     return faces
 
-
-
 def process_custom_axes(axis_names):
     """Parses the custom_axes option from the command line"""
     return axis_names.strip().strip("'").strip('"').split(',')
@@ -477,7 +670,8 @@ def get_custom_coords(axis_names,mapping, coords):
     """
     for i, axis in enumerate(reversed(axis_names)):
         if not axis in mapping[0]:
-            print 'Warning: could not find custom axis',axis,'in map headers:',mapping[0]
+            raise ValueError, 'Warning: could not find custom axis %s in map headers: %s' \
+                % (axis, mapping[0])
         else:
             # get index of column in mapping file
             col_idx = mapping[0].index(axis)
@@ -759,7 +953,8 @@ def generate_3d_plots(prefs, data, custom_axes, background_color, label_color, \
                         dir_path='',data_file_path='',filename=None, \
                         default_filename='out', ellipsoid_prefs=None, \
                         user_supplied_edges=False, ball_scale=1.0, \
-                        arrow_colors={'line_color': 'white', 'head_color': 'red'}):
+                        arrow_colors={'line_color': 'white', 'head_color': 'red'}, \
+                        add_vectors=None):
     """Make 3d plots according to coloring options in prefs."""
     
     if filename is None:
@@ -780,15 +975,37 @@ def generate_3d_plots(prefs, data, custom_axes, background_color, label_color, \
     taxa = None
     if data.has_key('taxa'):
         taxa = data['taxa']
-
+    
     res = make_3d_plots(coord_header, coords, pct_var,mapping,prefs, \
                         background_color,label_color, \
                         taxa, custom_axes=custom_axes,edges=edges, \
                         coords_low=coords_low, coords_high=coords_high, \
                         ellipsoid_prefs=ellipsoid_prefs, \
                         user_supplied_edges=user_supplied_edges, \
-                        ball_scale=ball_scale, arrow_colors=arrow_colors)
-
+                        ball_scale=ball_scale, arrow_colors=arrow_colors,
+                        add_vectors=add_vectors)
+    
+    
+    # Validating if we should add RMS values
+    if add_vectors and add_vectors['rms_algorithm'] and add_vectors['vectors'] and add_vectors['rms_path']:
+        f_rms = open(os.path.join(htmlpath,add_vectors['rms_path']), 'w')
+        
+        f_rms.write('Method to calculate the RMS: %s\n\n' % add_vectors['rms_algorithm'])
+        
+        for group in add_vectors['rms_output']:
+            to_test = {}
+            for cat in add_vectors['rms_output'][group]:
+                if len(add_vectors['rms_output'][group][cat]['rms_vector']) != 0:
+                    to_test[cat] = add_vectors['rms_output'][group][cat]['rms_vector']
+                else:
+                    add_vectors['rms_output'][group][cat]['rms_result'] = nan
+            
+            group_means, prob = run_ANOVA_trajetories(to_test)
+            f_rms.write('Grouped by %s, probability: %f\nGroup means (ANOVA): %s\n\n' \
+                % (group, prob, group_means))
+            
+        f_rms.close()
+    
     #Write kinemage file
     f = open(kinpath, 'w')
     f.write('\n'.join(res))
