@@ -7,7 +7,7 @@ __author__ = "Jesse Stombaugh"
 __copyright__ = "Copyright 2011, The QIIME Project" 
 __credits__ = ["Jesse Stombaugh"] #remember to add yourself
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Jesse Stombaugh"
 __email__ = "jesse.stombaugh@colorado.edu"
 __status__ = "Release"
@@ -208,7 +208,7 @@ def get_otu_counts(fpath, data):
         raise MissingFileError, 'OTU Count file required for this analysis'
     
     if lineages==[]:
-        raise ValueError, '\n\nThe lineages are missing from the OTU table.  If you used single_rarefaction.py to create your otu_table, make sure you pass the "--lineages_included" option.\n'
+        raise ValueError, '\n\nThe lineages are missing from the OTU table. Make sure you included the lineages for the OTUs in your OTU table. \n'
         
     return sample_ids,otu_ids,otu_table,lineages
 
