@@ -6,7 +6,7 @@ __author__ = "Catherine Lozupone"
 __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Catherine Lozupone, Jesse Stombaugh, and Dan Knights"]
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Catherine Lozupone"
 __email__ = "lozupone@colorado.edu"
 __status__ = "Release"
@@ -15,12 +15,11 @@ __status__ = "Release"
 from optparse import OptionParser
 from os.path import split, splitext, join
 from os import listdir
-from numpy import argsort, mean
+from numpy import argsort, mean, array
 from cogent.util.dict2d import Dict2D
 from cogent.maths.stats.test import calc_contingency_expected, G_fit_from_Dict2D,\
     ANOVA_one_way, correlation, t_paired
 from cogent.maths.stats.util import Numbers
-from numpy import array
 import sys
 from qiime.util import convert_OTU_table_relative_abundance
 import numpy as np
@@ -39,7 +38,7 @@ from qiime.longitudinal_otu_category_significance import get_sample_individual_i
 """
 
 def filter_OTUs(OTU_sample_info, filter, all_samples=True,\
-                category_mapping_info=None):
+                category_mapping_info=None, max_filter=None):
     """Get the list of OTUs found in at least <filter> samples                                                                      
                                                                                                                                      
     optionally filters out those that are found in all_samples if True:                                                              
@@ -50,7 +49,11 @@ def filter_OTUs(OTU_sample_info, filter, all_samples=True,\
     optionally takes a category mapping file as input and only considers                                                             
         inclusion in samples that are included therein. This is a method                                                             
         of making sure that the samples represented in the category                                                                  
-        mapping file and the OTU table are in sync                                                                                   
+        mapping file and the OTU table are in sync         
+
+    
+    If max_filter is set, it will exclude OTUs from the list that are 
+        found above that value.
     """
     result = []
     for OTU in OTU_sample_info:
@@ -71,9 +74,12 @@ def filter_OTUs(OTU_sample_info, filter, all_samples=True,\
                     samples.append(sample)
 
         if len(samples) >= int(filter):
-            if all_samples:
+            if all_samples and not max_filter:
                 if len(samples) < len(included_samples):
                     result.append(OTU)
+            elif max_filter:
+                if len(samples) <= int(max_filter):
+                    result.append(OTU)
             else:
                 result.append(OTU)
     return result
@@ -357,7 +363,7 @@ def output_results_G_test(G_test_results, taxonomy_info=None):
         if taxonomy_info:
             line.append(taxonomy_info[OTU])
         output.append('\t'.join(line))
-    return output
+    return sort_rows(output, 2)
 
 def output_results_ANOVA(ANOVA_results, category_values, taxonomy_info=None):
     """creates the results output using result of run_ANOVA_OTUs"""
@@ -379,7 +385,7 @@ def output_results_ANOVA(ANOVA_results, category_values, taxonomy_info=None):
         if taxonomy_info:
             line.append(taxonomy_info[OTU])
         output.append('\t'.join(line))
-    return output
+    return sort_rows(output, 1)
 
 def output_results_correlation(correlation_results, taxonomy_info=None):
     """creates the results output using result of run_correlation_OTUs"""
@@ -400,7 +406,7 @@ def output_results_correlation(correlation_results, taxonomy_info=None):
         if taxonomy_info:
             line.append(taxonomy_info[OTU])
         output.append('\t'.join(line))
-    return output
+    return sort_rows(output, 1)
 
 def output_results_paired_T_test(paired_T_results, taxonomy_info=None):
     """creates the results output using result of run_paired_T_test_OTUs
@@ -423,7 +429,23 @@ def output_results_paired_T_test(paired_T_results, taxonomy_info=None):
         if taxonomy_info:
             line.append(taxonomy_info[OTU])
         output.append('\t'.join(line))
-    return output
+    return sort_rows(output, 1)
+
+def sort_rows(output, p_val_index):
+    """sorts the rows in the output by p-value
+    """
+    header = output[0]
+    lines = output[1:]
+    probs = []
+    for line in lines:
+        line = line.split('\t')
+        probs.append(float(line[p_val_index]))
+    probs = array(probs)
+    x = probs.argsort()
+    new_lines = [header]
+    for i in x:
+        new_lines.append(lines[i])
+    return new_lines
 
 def add_bonferroni_to_results(results):
     """corrects results using the false discovery rate method.
@@ -474,10 +496,10 @@ def fdr_correction(probs):
     corrected_probs = [None] * len(probs)
     for rank, index in enumerate(argsort(probs)):
         correction = len(probs) / float(rank + 1)
-        if probs[index]:
-            fdr_p = probs[index] * correction
-        else:
-            fdr_p = 'NA'
+#        if probs[index]:
+        fdr_p = probs[index] * correction
+#        else:
+#            fdr_p = 'NA'
         corrected_probs[index] = fdr_p
     return corrected_probs
 
