@@ -9,7 +9,7 @@ __author__ = "Greg Caporaso"
 __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Greg Caporaso","Justin Kuczynski"] 
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 __status__ = "Release"
@@ -18,7 +18,7 @@ __status__ = "Release"
 def get_job_commands(python_exe_fp,rarefaction_fp,job_prefix,\
     input_fp,output_dir,working_dir,min_seqs,max_seqs,step,num_reps,\
     lineages_included, command_prefix=None,command_suffix=None):
-    """Generate alpha diversity commands to be submitted to cluster
+    """Generate rarefaction diversity commands to be submitted to cluster
     """
     # Create data for each run (depth, output_fn)
     run_parameters = []
@@ -34,9 +34,9 @@ def get_job_commands(python_exe_fp,rarefaction_fp,job_prefix,\
     result_filepaths = []
     
     if lineages_included:
-        lineages_included_param = '--lineages_included'
-    else:
         lineages_included_param = ''
+    else:
+        lineages_included_param = '--suppress_lineages_included'
     
     for depth,output_fn in run_parameters:
         # Each run ends with moving the output file from the tmp dir to
