@@ -6,7 +6,7 @@ __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Rob Knight", "Daniel McDonald", "Greg Caporaso",
     "Justin Kuczynski", "Cathy Lozupone", "Jens Reeder", "Antonio Gonzalez Pena"]
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 __status__ = "Release"
@@ -21,12 +21,15 @@ from numpy.random import permutation
 from cogent.parse.record_finder import LabeledRecordFinder
 from cogent.parse.fasta import FastaFinder
 from cogent.parse.tree import DndParser
+from cogent.parse.fastq import MinimalFastqParser as MinimalFastqParserCogent
 from cogent.core.tree import PhyloNode
 from copy import deepcopy
 import os
 import re
 from cogent import DNA
 
+def MinimalFastqParser(data,strict=False):
+    return MinimalFastqParserCogent(data,strict=strict)
 
 class QiimeParseError(Exception):
     pass
@@ -102,7 +105,11 @@ def parse_mapping_file(lines, strip_quotes=True, suppress_stripping=False):
             else:
                 comments.append(line)
         else:
-            mapping_data.append(map(strip_f, line.split('\t')))
+            # Will add empty string to empty fields
+            tmp_line = map(strip_f, line.split('\t'))
+            if len(tmp_line)<len(header):
+                tmp_line.extend(['']*(len(header)-len(tmp_line)))
+            mapping_data.append(tmp_line)
     if not header:
         raise QiimeParseError, "No header line was found in mapping file."
     if not mapping_data:
