@@ -6,25 +6,23 @@ __author__ = "William Walters"
 __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["William Walters"]
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "William Walters"
 __email__ = "William.A.Walters@colorado.edu"
 __status__ = "Release"
  
+from matplotlib import use
+use('Agg',warn=False)
 from cogent.parse.fasta import MinimalFastaParser
 from numpy import arange, std, average
 from pylab import plot, savefig, xlabel, ylabel, text, \
     hist, figure, legend, title, show, xlim ,ylim, xticks, yticks,\
     scatter, subplot
 from matplotlib.font_manager import fontManager, FontProperties
-
 from qiime.parse import parse_qual_score
 
 
 
-    
-        
-        
 def bin_qual_scores(qual_scores):
     """ Bins qual score according to nucleotide position 
     
