@@ -28,7 +28,7 @@ __author__ = "Rob Knight and Micah Hamady"
 __copyright__ = "Copyright 2011, The QIIME Project" 
 __credits__ = ["Rob Knight", "Micah Hamady", "Greg Caporaso", "Kyle Bittinger","Jesse Stombaugh","William Walters","Jens Reeder"] #remember to add yourself
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "William Walters"
 __email__ = "rob@spot.colorado.edu, william.a.walters@colorado.edu"
 __status__ = "Release"
@@ -37,6 +37,7 @@ import re
 from gzip import GzipFile
 from os import mkdir, stat
 from collections import defaultdict
+from string import upper
 
 from numpy import array, mean, arange, histogram
 from numpy import __version__ as numpy_version
@@ -273,6 +274,9 @@ def check_map(infile, disable_primer_check, added_demultiplex_field=None,
         disable_primer_check=disable_primer_check,
         added_demultiplex_field=added_demultiplex_field)
         
+    if errors or warnings:
+        raise ValueError,('Problems were found with mapping file, '+\
+         'please run check_id_map.py to identify problems.')
     
     barcode_to_sample_id = {}
     
@@ -530,7 +534,8 @@ def check_seqs(fasta_out, fasta_files, starting_ix, valid_map, qual_mappings,
     primer_seqs_lens, all_primers, max_primer_mm, disable_primer_check,
     reverse_primers, rev_primers, qual_out, qual_score_window=0,
     discard_bad_windows=False, min_qual_score=25, min_seq_len=200,
-    median_length_filtering=None, added_demultiplex_field=None):
+    median_length_filtering=None, added_demultiplex_field=None,
+    reverse_primer_mismatches=0):
     """Checks fasta-format sequences and qual files for validity."""
     
     
@@ -560,6 +565,7 @@ def check_seqs(fasta_out, fasta_files, starting_ix, valid_map, qual_mappings,
     for fasta_in in fasta_files:
         for curr_id, curr_seq in MinimalFastaParser(fasta_in):
             curr_rid = curr_id.split()[0]
+            curr_seq = upper(curr_seq)
 
             curr_len = len(curr_seq)
             curr_qual = qual_mappings.get(curr_rid, None)
@@ -674,7 +680,7 @@ def check_seqs(fasta_out, fasta_files, starting_ix, valid_map, qual_mappings,
                     rev_primer = rev_primers[curr_bc]
                     rev_primer_mm, rev_primer_index  = \
                      local_align_primer_seq(rev_primer,cres)
-                    if rev_primer_mm <= max_primer_mm:
+                    if rev_primer_mm <= reverse_primer_mismatches:
                         write_seq = write_seq[0:rev_primer_index]
                         if qual_out:
                             curr_qual = curr_qual[0:barcode_len +\
@@ -688,7 +694,7 @@ def check_seqs(fasta_out, fasta_files, starting_ix, valid_map, qual_mappings,
                     rev_primer = rev_primers[curr_bc]
                     rev_primer_mm, rev_primer_index  = \
                      local_align_primer_seq(rev_primer,cres)
-                    if rev_primer_mm <= max_primer_mm:
+                    if rev_primer_mm <= reverse_primer_mismatches:
                         write_seq = write_seq[0:rev_primer_index]
                         if qual_out:
                             curr_qual = curr_qual[0:barcode_len +\
@@ -1036,7 +1042,8 @@ def preprocess(fasta_files, qual_files, mapping_file,
     dir_prefix='.', max_bc_errors=2, max_homopolymer=4,
     retain_unassigned_reads=False, keep_barcode=False, 
     attempt_bc_correction=True, qual_score_window=0,
-    disable_primer_check=False, reverse_primers='disable', 
+    disable_primer_check=False, reverse_primers='disable',
+    reverse_primer_mismatches=0,
     record_qual_scores=False, discard_bad_windows=False, 
     median_length_filtering=None, added_demultiplex_field=None):
         
@@ -1105,6 +1112,9 @@ def preprocess(fasta_files, qual_files, mapping_file,
     mismatches allowed for a reverse primer match are the same as specified 
     for the forward primer mismatches with the -M parameter (default 0).
     
+    reverse_primer_mismatches: Number of reverse primer mismatches allowed.
+    reverse_primers must be enabled for this to do anything.
+    
     record_qual_scores:  (default False) Will record quality scores for all
     sequences that are written to the output seqs.fna file in a separate
     file (seqs_filtered.qual) containing the same sequence IDs and 
@@ -1329,7 +1339,8 @@ def preprocess(fasta_files, qual_files, mapping_file,
         primer_seqs_lens, all_primers, max_primer_mm, disable_primer_check,
         reverse_primers, rev_primers, qual_out, qual_score_window,
         discard_bad_windows, min_qual_score, min_seq_len,
-        median_length_filtering, added_demultiplex_field)
+        median_length_filtering, added_demultiplex_field,
+        reverse_primer_mismatches)
 
     # Write log file
     log_file = open(dir_prefix + '/' + "split_library_log.txt", 'w+')
