@@ -5,7 +5,7 @@ __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Rob Knight", "Daniel McDonald", "Greg Caporaso", 
 "Justin Kuczynski","Jens Reeder","Catherine Lozupone"] #remember to add yourself if you make changes
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 __status__ = "Release"
@@ -27,12 +27,14 @@ import os
 from copy import deepcopy
 from datetime import datetime
 from subprocess import Popen, PIPE, STDOUT
+from random import random
+
 from numpy import min, max, median, mean
 import numpy
 from numpy.ma import MaskedArray
 from numpy.ma.extras import apply_along_axis
 from numpy import array, zeros, argsort, shape, vstack,ndarray, asarray, \
-        float, where, isnan, mean, std
+        float, where, isnan, mean, std, sqrt, ravel
         
 from cogent.util.dict2d import Dict2D
 from cogent import LoadSeqs, Sequence,DNA
@@ -46,7 +48,6 @@ from cogent.app.blast import Blastall
 from cogent.app.util import get_tmp_filename as cogent_get_tmp_filename, FilePath
 from cogent.parse.blast import BlastResult
 from cogent.parse.fasta import MinimalFastaParser
-from cogent.parse.fastq import MinimalFastqParser
 from cogent.util.misc import remove_files
 from cogent.util.dict2d import Dict2D
 from cogent.app.formatdb import build_blast_db_from_fasta_path,\
@@ -61,9 +62,11 @@ from qiime.parse import (parse_otu_table,
                          parse_qiime_config_files,
                          parse_coords,
                          parse_newick,
+                         fields_to_dict,
                          PhyloNode,
                          parse_mapping_file,
-                         parse_denoiser_mapping)
+                         parse_denoiser_mapping,
+                         MinimalFastqParser)
 from qiime.format import format_otu_table
 
 class TreeMissingError(IOError):
@@ -84,6 +87,7 @@ class MissingFileError(IOError):
 class FileFormatError(IOError):
     """Exception for wrong file format"""
     pass
+    
 
 def make_safe_f(f, allowed_params):
     """Make version of f that ignores extra named params."""
@@ -660,15 +664,20 @@ def merge_otu_tables(otu_table_f1,otu_table_f2):
         sample_ids2, otu_ids2, otu_table2, lineages2 =\
             parse_otu_table(otu_table_f2)
     
-    assert set(sample_ids1) & set(sample_ids2) == set(),\
-     'Overlapping sample ids detected.'
-    sample_ids_result = sample_ids1 + sample_ids2
-    sample_ids_result_lookup = dict(
-     [(sid,i) for i, sid in enumerate(sample_ids_result)])
+    # assert set(sample_ids1) & set(sample_ids2) == set(),\
+    #  'Overlapping sample ids detected:\n %s' %\
+    #  ' '.join(set(sample_ids1) & set(sample_ids2))
+    sample_ids_result = []
+    sample_ids_result_lookup = {}
+    i = 0
+    for sid in sample_ids1 + sample_ids2:
+        if sid not in sample_ids_result_lookup:
+            sample_ids_result.append(sid)
+            sample_ids_result_lookup[sid] = i
+            i += 1
+        else:
+            pass
     
-    # Will need to add support for OTU tables wo tax info at some 
-    # point -- in a rush now so don't have time to add it without an
-    # immediate use case.
     if lineages1 and lineages2:    
         # map OTU ids to lineages -- in case of conflicts (i.e, OTU assigned)
         # different lineage in different otu tables, the lineage from 
@@ -694,20 +703,16 @@ def merge_otu_tables(otu_table_f1,otu_table_f2):
     
     otu_table = zeros(shape=(len(otu_ids_result),len(sample_ids_result)),dtype=int)
     for i,sample_id in enumerate(sample_ids1):
-        #col_index = sample_ids_result.index(sample_id)
         col_index = sample_ids_result_lookup[sample_id]
         for j,otu_id in enumerate(otu_ids1):
-            #row_index = otu_ids_result.index(otu_id)
             row_index = otu_ids_result_lookup[otu_id]
             otu_table[row_index,col_index] = otu_table1[j,i]
         
     for i,sample_id in enumerate(sample_ids2):
-        #col_index = sample_ids_result.index(sample_id)
         col_index = sample_ids_result_lookup[sample_id]
         for j,otu_id in enumerate(otu_ids2):
-            #row_index = otu_ids_result.index(otu_id)
             row_index = otu_ids_result_lookup[otu_id]
-            otu_table[row_index,col_index] = otu_table2[j,i]
+            otu_table[row_index,col_index] += otu_table2[j,i]
     
     if lineages:
         lineages_result = [otu_id_to_lineage[otu_id] 
@@ -1139,16 +1144,16 @@ def inflate_denoiser_output(centroid_seqs,singleton_seqs,denoiser_map,raw_seqs):
     
 ## Functions for counting sequences in fasta files
 
-def count_seqs(fasta_filepath):
+def count_seqs(fasta_filepath,parser=MinimalFastaParser):
     """ Count the sequences in fasta_filepath 
     
         fasta_filepath: string indicating the full path to the file
     """
     # Open the file and pass it to py_count_seqs_from_file -- wrapping
     # this makes for easier unit testing
-    return count_seqs_from_file(open(fasta_filepath))
+    return count_seqs_from_file(open(fasta_filepath,'U'),parser=parser)
 
-def count_seqs_from_file(fasta_file):
+def count_seqs_from_file(fasta_file,parser=MinimalFastaParser):
     """Return number of sequences in fasta_file (no format checking performed)
     
         fasta_file: an open file object
@@ -1156,9 +1161,9 @@ def count_seqs_from_file(fasta_file):
     """
     result = 0
     lens = []
-    for seq_id,seq in MinimalFastaParser(fasta_file):
+    for record in parser(fasta_file):
         result += 1
-        lens.append(len(seq))
+        lens.append(len(record[1]))
     if result == 0:
         return result, None, None
     else:
@@ -1179,9 +1184,16 @@ def count_seqs_in_filepaths(fasta_filepaths,seq_counter=count_seqs):
     inaccessible_filepaths = []
     # iterate over the input files
     for fasta_filepath in fasta_filepaths:
+        # if the file is actually fastq, use the fastq parser. 
+        # otherwise use the fasta parser
+        if fasta_filepath.endswith('.fastq'):
+            parser = MinimalFastqParser
+        else:
+            parser = MinimalFastaParser
+        
         try:
             # get the count of sequences in the current file
-            current_count = seq_counter(fasta_filepath)
+            current_count = seq_counter(fasta_filepath,parser=parser)
             # store it
             counts.append((current_count,fasta_filepath))
             # and increment the total count
@@ -1271,7 +1283,7 @@ def get_split_libraries_fastq_params_and_file_types(fastq_fps,mapping_fp):
     
     # determine which barcode direction is correct
     if rev_count > fwd_count:
-        barcode_orientation='--rev_comp_barcode'
+        barcode_orientation='--rev_comp_mapping_barcodes'
     else:
         barcode_orientation=''
     
@@ -1349,4 +1361,83 @@ def make_compatible_distance_matrices(dm1,dm2,lookup=None):
     
 def get_rdp_jarpath():
     """ Return jar file name for RDP classifier ($RDP_JAR_PATH)"""
-    return getenv('RDP_JAR_PATH')
\ No newline at end of file
+    return getenv('RDP_JAR_PATH')
+    
+def expand_otu_ids(otu_map,otus_to_expand,ignore_missing=False):
+    """From OTU map and otu ids, return seq ids represented by the OTUs
+    """
+    result = []
+    for o in otus_to_expand:
+        otu_id = o.split()[0]
+        try:
+            result += otu_map[otu_id]
+        except KeyError:
+            if ignore_missing:
+                continue
+            else:
+                raise KeyError,\
+                 "OTU id not in OTU map: %s" % o.split()[0]
+    return result
+# This function (stderr) was pulled from the following website: 
+# http://www.java2s.com/Open-Source/Python/Math/SciPy/scipy/scipy/stats/stats.py.htm
+# then modified to fit the purpose needed. Originally from Scipy.
+def stderr(a, axis=0, ddof=1):
+    """ Returns the estimated population standard error of the values in the
+        passed array (i.e., N-1).  Axis can equal None (ravel array
+        first), or an integer (the axis over which to operate).
+    """
+    a, axis = _chk_asarray(a, axis)
+    return std(a,axis,ddof=1) / float(sqrt(a.shape[axis]))
+
+# This function (_chk_asarray) was pulled from the following website: 
+# http://www.java2s.com/Open-Source/Python/Math/SciPy/scipy/scipy/stats/stats.py.htm
+# then modified to fit the purpose needed. Originally from Scipy.
+def _chk_asarray(a, axis):
+    """ Converts a list into an numpy array """
+    if axis is None:
+        a = ravel(a)
+        outaxis = 0
+    else:
+        a = asarray(a)
+        outaxis = axis
+    return a, outaxis
+
+
+def subsample_fasta(input_fasta_fp,
+                    output_fp,
+                    percent_subsample):
+    """ Writes random percent_sample of sequences from input fasta filepath
+    
+    input_fasta_fp: input fasta filepath
+    output_fp: output fasta filepath
+    percent_subsample: percent of sequences to write
+    """
+    
+    input_fasta = open(input_fasta_fp, "U")
+    
+    output_fasta = open(output_fp, "w")
+
+    for label, seq in MinimalFastaParser(input_fasta):
+        if random() < percent_subsample:
+            output_fasta.write('>%s\n%s\n' % (label, seq))
+
+def summarize_otu_sizes_from_otu_map(otu_map_f):
+    """ Given an otu map file handle, summarizes the sizes of the OTUs
+    
+        This is useful for determining number of singletons, doubletons, etc
+         from an OTU map.
+    """
+    result = {}
+    for otu_id, seq_ids in fields_to_dict(otu_map_f).items():
+        otu_size = len(seq_ids)
+        try:
+            result[otu_size] += 1
+        except KeyError:
+            result[otu_size] = 1
+    
+    result = result.items()
+    result.sort()
+    return result
+
+
+
