@@ -9,6 +9,7 @@ from glob import glob
 from os.path import split, splitext, join, dirname, abspath
 from datetime import datetime
 from numpy import array
+from cogent.util.misc import safe_md5
 from cogent.parse.fasta import MinimalFastaParser
 from qiime.parse import parse_mapping_file, parse_qiime_parameters
 from qiime.format import format_otu_table
@@ -24,7 +25,7 @@ __author__ = "Greg Caporaso"
 __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Greg Caporaso", "Kyle Bittinger", "Justin Kuczynski"]
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 __status__ = "Release"
@@ -168,12 +169,19 @@ def validate_and_set_jobs_to_start(params,
        not parallel:
         option_parser.error("Passing -O requires that -a is also passed.")
     params['parallel']['jobs_to_start'] = str(jobs_to_start)
+
+def log_input_md5s(logger,fps):
+    logger.write("Input file md5 sums:\n")
+    for fp in fps:
+        if fp != None:
+            logger.write("%s: %s\n" % (fp, safe_md5(open(fp)).hexdigest()))
+    logger.write("\n")
     
 
 ## End utilities used by the workflow functions
 
 ## Begin task-specific workflow functions
-def run_qiime_data_preparation(input_fp, 
+def run_pick_otus_through_otu_table(input_fp, 
                                output_dir, 
                                command_handler,
                                params, 
@@ -202,6 +210,7 @@ def run_qiime_data_preparation(input_fp,
     commands = []
     python_exe_fp = qiime_config['python_exe_fp']
     script_dir = get_qiime_scripts_dir()
+    cluster_failures = False
     if logger == None:
         logger = WorkflowLogger(generate_log_fp(output_dir),
                                 params=params,
@@ -210,6 +219,8 @@ def run_qiime_data_preparation(input_fp,
     else:
         close_logger_on_success = False
     
+    log_input_md5s(logger,[input_fp])
+    
     # Prep the OTU picking command
     try:
         otu_picking_method = params['pick_otus']['otu_picking_method']
@@ -232,9 +243,19 @@ def run_qiime_data_preparation(input_fp,
             # option. This works for now though.
             d = params['pick_otus'].copy()
             del d['otu_picking_method']
-            params_str += ' %s' % get_params_str(d)
         except KeyError:
             pass
+        
+        if otu_picking_method == 'uclust_ref':
+            try:
+                suppress_new_clusters = d['suppress_new_clusters']
+                del d['suppress_new_clusters']
+                cluster_failures = False
+            except KeyError:
+                cluster_failures = True
+                failure_otu_picking_method = 'uclust'
+        
+        params_str += ' %s' % get_params_str(d)
         otu_picking_script = 'parallel_pick_otus_%s.py' % otu_picking_method
         # Build the OTU picking command
         pick_otus_cmd = '%s %s/%s -i %s -o %s -T %s' % (python_exe_fp, 
@@ -254,6 +275,46 @@ def run_qiime_data_preparation(input_fp,
 
     commands.append([('Pick OTUs', pick_otus_cmd)])
     
+    if cluster_failures:
+        reference_otu_fp = otu_fp
+        clustered_failures_dir = '%s/failure_otus/' % pick_otu_dir
+        
+        try:
+            d = params['pick_otus'].copy()
+            del d['otu_picking_method']
+        except KeyError:
+            pass
+
+        if 'uclust_otu_id_prefix' not in d:
+            d['uclust_otu_id_prefix'] = 'DeNovoOTU'        
+        params_str = ' %s' % get_params_str(d)
+
+        failures_list_fp = '%s/%s_failures.txt' % \
+         (pick_otu_dir,input_basename)
+        failures_fasta_fp = '%s/%s_failures.fasta' % \
+         (pick_otu_dir,input_basename)
+        
+        filter_fasta_cmd = 'filter_fasta.py -f %s -s %s -o %s' %\
+         (input_fp,failures_list_fp,failures_fasta_fp)
+        
+        commands.append([('Generate failures fasta file',
+                          filter_fasta_cmd)])
+        
+        # Prep the OTU picking command for
+        failure_otu_fp = '%s/%s_failures_otus.txt' % (clustered_failures_dir,input_basename)
+        # Build the OTU picking command
+        pick_otus_cmd = '%s %s/pick_otus.py -i %s -o %s -m %s %s' %\
+         (python_exe_fp, script_dir, failures_fasta_fp, clustered_failures_dir, 
+          failure_otu_picking_method, params_str)
+
+        commands.append([('Pick de novo OTUs for new clusters', pick_otus_cmd)])
+        
+        merged_otu_map_fp = '%s/merged_otu_map.txt' % clustered_failures_dir
+        cat_otu_tables_cmd = 'cat %s %s >> %s' %\
+         (reference_otu_fp,failure_otu_fp,merged_otu_map_fp)
+        commands.append([('Merge OTU maps',cat_otu_tables_cmd)])
+        otu_fp = merged_otu_map_fp
+
     # Prep the representative set picking command
     rep_set_dir = '%s/rep_set/' % output_dir
     try:
@@ -329,6 +390,15 @@ def run_qiime_data_preparation(input_fp,
     
     commands.append([('Make OTU table', make_otu_table_cmd)])
     
+    if cluster_failures:
+        reference_otu_table_fp = '%s/reference_only_otu_table.txt' % output_dir
+        # Build the OTU table building command
+        make_otu_table_cmd = '%s %s/make_otu_table.py -i %s -t %s -o %s %s' %\
+         (python_exe_fp, script_dir, reference_otu_fp, taxonomy_fp, 
+          reference_otu_table_fp, params_str)
+    
+        commands.append([('Make reference-only OTU table', make_otu_table_cmd)])
+    
     # Prep the pynast alignment command
     try:
         alignment_method = params['align_seqs']['alignment_method']
@@ -367,21 +437,17 @@ def run_qiime_data_preparation(input_fp,
          (python_exe_fp, script_dir, rep_set_fp, pynast_dir, params_str)
     commands.append([('Align sequences', align_seqs_cmd)])
     
-    if alignment_method == 'pynast':
-        # Prep the alignment filtering command (only applicable when aligned
-        # with pynast)
-        filtered_aln_fp = '%s/%s_rep_set_aligned_pfiltered.fasta' %\
-         (pynast_dir,input_basename)
-        try:
-            params_str = get_params_str(params['filter_alignment'])
-        except KeyError:
-            params_str = ''
-        # Build the alignment filtering command
-        filter_alignment_cmd = '%s %s/filter_alignment.py -o %s -i %s %s' %\
-         (python_exe_fp, script_dir, pynast_dir, aln_fp, params_str)
-        commands.append([('Filter alignment', filter_alignment_cmd)])
-    else: 
-        filtered_aln_fp = aln_fp
+    # Prep the alignment filtering command
+    filtered_aln_fp = '%s/%s_rep_set_aligned_pfiltered.fasta' %\
+     (pynast_dir,input_basename)
+    try:
+        params_str = get_params_str(params['filter_alignment'])
+    except KeyError:
+        params_str = ''
+    # Build the alignment filtering command
+    filter_alignment_cmd = '%s %s/filter_alignment.py -o %s -i %s %s' %\
+     (python_exe_fp, script_dir, pynast_dir, aln_fp, params_str)
+    commands.append([('Filter alignment', filter_alignment_cmd)])
     
     # Prep the tree building command
     tree_fp = '%s/rep_set.tre' % output_dir
@@ -402,7 +468,7 @@ def run_qiime_data_preparation(input_fp,
                     close_logger_on_success=close_logger_on_success)
     
     return abspath(tree_fp), abspath(otu_table_fp)
-    
+run_qiime_data_preparation = run_pick_otus_through_otu_table
     
     
 ## Start reference otu picking workflow
@@ -454,7 +520,9 @@ def run_pick_reference_otus_through_otu_table(
         close_logger_on_success = True
     else:
         close_logger_on_success = False
-    
+
+    log_input_md5s(logger,[input_fp,refseqs_fp,taxonomy_fp])
+
     # Prep the OTU picking command
     pick_otu_dir = '%s/%s_picked_otus' % (output_dir, otu_picking_method)
     otu_fp = '%s/%s_otus.txt' % (pick_otu_dir,input_basename)
@@ -491,13 +559,18 @@ def run_pick_reference_otus_through_otu_table(
             params_str = get_params_str(params['pick_otus'])
         except KeyError:
             params_str = ''
+        # Since this is reference-based OTU picking we always want to
+        # suppress new clusters -- force it here.
+        params_str+= ' --suppress_new_clusters'
+        logger.write("Forcing --suppress_new_clusters as this is reference-based OTU picking.\n\n")
         # Build the OTU picking command
-        pick_otus_cmd = '%s %s/pick_otus.py -i %s -o %s -r %s %s' %\
+        pick_otus_cmd = '%s %s/pick_otus.py -i %s -o %s -r %s -m %s %s' %\
          (python_exe_fp,
           script_dir,
           input_fp,
           pick_otu_dir,
           refseqs_fp,
+          otu_picking_method,
           params_str)
 
     commands.append([('Pick OTUs', pick_otus_cmd)])
@@ -530,9 +603,9 @@ def run_pick_reference_otus_through_otu_table(
 def run_beta_diversity_through_plots(otu_table_fp, mapping_fp,
     output_dir, command_handler, params, qiime_config,
     color_by_interesting_fields_only=True,sampling_depth=None,
+    histogram_categories=None,
     tree_fp=None, parallel=False, logger=None, suppress_3d_plots=False,
-    suppress_2d_plots=False, suppress_distance_histograms=False,
-    status_update_callback=print_to_stdout):
+    suppress_2d_plots=False,status_update_callback=print_to_stdout):
     """ Run the data preparation steps of Qiime 
     
         The steps performed by this function are:
@@ -562,8 +635,16 @@ def run_beta_diversity_through_plots(otu_table_fp, mapping_fp,
     else:
         close_logger_on_success = False
     
+    log_input_md5s(logger,[otu_table_fp,mapping_fp,tree_fp])
+    
     mapping_data, mapping_header, mapping_comments =\
      parse_mapping_file(open(mapping_fp,'U'))
+    if histogram_categories:
+        invalid_categories = set(histogram_categories) - set(mapping_header)
+        if invalid_categories:
+            raise ValueError,\
+             "Invalid histogram categories - these must exactly match "+\
+             "mapping file column headers: %s" % (' '.join(invalid_categories))
     # Get the interesting mapping fields to color by -- if none are
     # interesting, take all of them. Interesting is defined as those
     # which have greater than one value and fewer values than the number 
@@ -752,7 +833,7 @@ def run_beta_diversity_through_plots(otu_table_fp, mapping_fp,
               ('Make 2D plots (discrete coloring, %s)' %\
                 beta_diversity_metric,discrete_2d_command,)])
                 
-        if not suppress_distance_histograms:
+        if histogram_categories:
             # Prep the discrete-coloring 3d plots command
             histograms_dir = '%s/%s_histograms/' %\
              (output_dir, beta_diversity_metric)
@@ -766,9 +847,10 @@ def run_beta_diversity_through_plots(otu_table_fp, mapping_fp,
                 params_str = ''
             # Build the make_distance_histograms command
             distance_histograms_command = \
-             '%s %s/make_distance_histograms.py -d %s -o %s -m %s %s' %\
+             '%s %s/make_distance_histograms.py -d %s -o %s -m %s -f "%s" %s' %\
               (python_exe_fp, script_dir, beta_div_fp, 
-               histograms_dir, mapping_fp, params_str)
+               histograms_dir, mapping_fp, 
+               ','.join(histogram_categories), params_str)
        
             commands.append([\
               ('Make Distance Histograms (%s)' %\
@@ -785,8 +867,8 @@ def run_beta_diversity_through_plots(otu_table_fp, mapping_fp,
 
 def run_qiime_alpha_rarefaction(otu_table_fp, mapping_fp,
     output_dir, command_handler, params, qiime_config, tree_fp=None,
-    num_steps=10, parallel=False, logger=None, min_seqs_per_sample=10,
-    status_update_callback=print_to_stdout):
+    num_steps=10, parallel=False, logger=None, min_rare_depth=10,
+    max_rare_depth=None,status_update_callback=print_to_stdout):
     """ Run the data preparation steps of Qiime 
     
         The steps performed by this function are:
@@ -811,6 +893,8 @@ def run_qiime_alpha_rarefaction(otu_table_fp, mapping_fp,
     else:
         close_logger_on_success = False
     
+    log_input_md5s(logger,[otu_table_fp,mapping_fp,tree_fp])
+    
     # Prep the rarefaction command
     try:
         otu_table_f = open(otu_table_fp,'U')
@@ -820,11 +904,12 @@ def run_qiime_alpha_rarefaction(otu_table_fp, mapping_fp,
                      'Original Error:\n%s\n' % str(e))
         logger.close()
         raise IOError,e
-    
-    min_count, max_count, median_count, mean_count, counts_per_sample =\
-     compute_seqs_per_library_stats(otu_table_f)
-    step = int((median_count - min_seqs_per_sample) / num_steps) or 1
-    median_count = int(median_count)
+    if max_rare_depth == None:
+        min_count, max_count, median_count, mean_count, counts_per_sample =\
+         compute_seqs_per_library_stats(otu_table_f)
+        max_rare_depth = median_count
+    step = int((max_rare_depth - min_rare_depth) / num_steps) or 1
+    max_rare_depth = int(max_rare_depth)
     
     rarefaction_dir = '%s/rarefaction/' % output_dir
     try:
@@ -840,13 +925,13 @@ def run_qiime_alpha_rarefaction(otu_table_fp, mapping_fp,
         # Build the rarefaction command
         rarefaction_cmd = \
          '%s %s/parallel_multiple_rarefactions.py -T -i %s -m %s -x %s -s %s -o %s %s' %\
-         (python_exe_fp, script_dir, otu_table_fp, min_seqs_per_sample, median_count, \
+         (python_exe_fp, script_dir, otu_table_fp, min_rare_depth, max_rare_depth, \
           step, rarefaction_dir, params_str)
     else:
         # Build the rarefaction command
         rarefaction_cmd = \
          '%s %s/multiple_rarefactions.py -i %s -m %s -x %s -s %s -o %s %s' %\
-         (python_exe_fp, script_dir, otu_table_fp, min_seqs_per_sample, median_count, \
+         (python_exe_fp, script_dir, otu_table_fp, min_rare_depth, max_rare_depth, \
           step, rarefaction_dir, params_str)
     commands.append([('Alpha rarefaction', rarefaction_cmd)])
     
@@ -860,19 +945,21 @@ def run_qiime_alpha_rarefaction(otu_table_fp, mapping_fp,
         params_str = get_params_str(params['alpha_diversity'])
     except KeyError:
         params_str = ''
+    if tree_fp:
+        params_str += ' -t %s' % tree_fp
     if parallel:
         params_str += ' %s' % get_params_str(params['parallel'])   
         # Build the alpha diversity command
         alpha_diversity_cmd = \
-         "%s %s/parallel_alpha_diversity.py -T -i %s -o %s -t %s %s" %\
+         "%s %s/parallel_alpha_diversity.py -T -i %s -o %s %s" %\
          (python_exe_fp, script_dir, rarefaction_dir, alpha_diversity_dir, \
-          tree_fp, params_str)
+          params_str)
     else:  
         # Build the alpha diversity command
         alpha_diversity_cmd = \
-         "%s %s/alpha_diversity.py -i %s -o %s -t %s %s" %\
+         "%s %s/alpha_diversity.py -i %s -o %s %s" %\
          (python_exe_fp, script_dir, rarefaction_dir, alpha_diversity_dir, \
-          tree_fp, params_str)
+          params_str)
 
     commands.append(\
      [('Alpha diversity on rarefied OTU tables',alpha_diversity_cmd)])
@@ -955,6 +1042,9 @@ def run_jackknifed_beta_diversity(otu_table_fp,tree_fp,seqs_per_sample,
         close_logger_on_success = True
     else:
         close_logger_on_success = False
+    
+    log_input_md5s(logger,[otu_table_fp,mapping_fp,tree_fp])
+    
     try:
         beta_diversity_metrics = params['beta_diversity']['metrics'].split(',')
     except KeyError:
@@ -1213,7 +1303,7 @@ def run_core_qiime_analyses(
     sampling_depth=None,
     even_sampling_keeps_all_samples=False,
     suppress_split_libraries=False,
-    arare_min_seqs_per_sample=10,
+    arare_min_rare_depth=10,
     arare_num_steps=10,
     reference_tree_fp=None,
     parallel=False,
@@ -1252,6 +1342,10 @@ def run_core_qiime_analyses(
     logger = WorkflowLogger(log_fp,
                             params=params,
                             qiime_config=qiime_config)
+    input_fps = fna_fps.split(',') + [mapping_fp]
+    if qual_fps != None:
+        input_fps += qual_fps.split(',')
+    log_input_md5s(logger,input_fps)
     
     ## Split libraries
     # Prep the split_libraries command
@@ -1337,6 +1431,7 @@ def run_core_qiime_analyses(
      params=params,
      qiime_config=qiime_config,
      sampling_depth=None,
+     histogram_categories=categories,
      tree_fp=tree_fp,
      parallel=parallel,
      logger=logger,
@@ -1404,6 +1499,7 @@ def run_core_qiime_analyses(
          params=params,
          qiime_config=qiime_config,
          sampling_depth=sampling_depth,
+         histogram_categories=categories,
          tree_fp=tree_fp,
          parallel=parallel,
          logger=logger,
@@ -1470,7 +1566,7 @@ def run_core_qiime_analyses(
      num_steps=arare_num_steps,
      parallel=parallel,
      logger=logger,
-     min_seqs_per_sample=arare_min_seqs_per_sample,
+     min_rare_depth=arare_min_rare_depth,
      status_update_callback=status_update_callback)
     
     index_links.append(('Alpha rarefaction plots',
@@ -1546,6 +1642,7 @@ def run_summarize_taxa_through_plots(otu_table_fp, mapping_fp,
         close_logger_on_success = True
     else:
         close_logger_on_success = False
+    log_input_md5s(logger,[otu_table_fp,mapping_fp])
     
     # Prep the summarize otu by category command
     try:
@@ -1723,7 +1820,7 @@ def run_ampliconnoise(mapping_fp,
         close_logger_on_success = True
     else:
         close_logger_on_success = False
-
+    log_input_md5s(logger,[mapping_fp,sff_txt_fp])
 
     # execute commands in output_dir
     called_dir = os.getcwd()
