@@ -42,3 +42,5 @@ rm -rf wf_jack ; jackknifed_beta_diversity.py -i otus/otu_table.txt -t otus/rep_
 echo "Make Bootstrapped Tree"
 make_bootstrapped_tree.py -m wf_jack/unweighted_unifrac/upgma_cmp/master_tree.tre -s wf_jack/unweighted_unifrac/upgma_cmp/jackknife_support.txt -o wf_jack/unweighted_unifrac/upgma_cmp/jackknife_named_nodes.pdf
 
+echo "Make Bi-Plots"
+rm -rf 3d_biplot ; make_3d_plots.py -i wf_bdiv_even146/unweighted_unifrac_pc.txt -m Fasting_Map.txt -t wf_taxa_summary/otu_table_L3.txt --n_taxa_keep 5 -o 3d_biplot
