@@ -6,7 +6,7 @@ __author__ = "Greg Caporaso"
 __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Greg Caporaso"]
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 __status__ = "Release"
@@ -70,6 +70,12 @@ script_info['optional_options']=[\
  make_option('-t','--tree_fp',\
             help='path to the tree file [default: %default; '+\
             'REQUIRED for phylogenetic measures]'),
+ make_option('--min_rare_depth',type='int',\
+            help='the lower limit of rarefaction depths '+\
+            '[default: %default]',default=10),
+ make_option('-e','--max_rare_depth',type='int',\
+            help='the upper limit of rarefaction depths '+\
+            '[default: median sequence/sample count]'),
  options_lookup['jobs_to_start_workflow']]
 script_info['version'] = __version__
 
@@ -85,6 +91,8 @@ def main():
     verbose = opts.verbose
     print_only = opts.print_only
     parallel = opts.parallel
+    min_rare_depth = opts.min_rare_depth
+    max_rare_depth = opts.max_rare_depth
     
     if opts.parameter_fp:
         try:
@@ -137,6 +145,8 @@ def main():
      tree_fp=tree_fp,\
      num_steps=num_steps,\
      parallel=parallel,\
+     min_rare_depth=min_rare_depth,
+     max_rare_depth=max_rare_depth,
      status_update_callback=status_update_callback)
 
 if __name__ == "__main__":
