@@ -6,7 +6,7 @@ __author__ = "Greg Caporaso"
 __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Greg Caporaso","Dan Knights"]
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 __status__ = "Release"
@@ -84,6 +84,10 @@ script_info['optional_options'] = [\
               help=("Enable preservation of intermediate uclust (.uc) files "
               "that are used to generate clusters via uclust. "
               "[default: %default]")),
+    make_option('--uclust_otu_id_prefix',default=None,
+              help=("OTU identifier prefix (string) for the de novo uclust" 
+                    " OTU picker [default: %default, OTU ids are ascending"
+                    " integers]")),
     #Define parallel-script-specific parameters
     make_option('-N','--pick_otus_fp',action='store',\
            type='string',help='full path to '+\
