@@ -6,7 +6,7 @@ __author__ = "Jesse Stombaugh"
 __copyright__ = "Copyright 2011, The QIIME project"
 __credits__ = ["Jesse Stombaugh","Julia Goodrich", "Justin Kuczynski"]
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Jesse Stombaugh"
 __email__ = "jesse.stombaugh@colorado.edu"
 __status__ = "Release"
@@ -145,10 +145,9 @@ def main():
     matplotlib_version = re.split("[^\d]", matplotlib.__version__)
     matplotlib_version_info = tuple([int(i) for i in matplotlib_version if \
                             i.isdigit()])
-    if matplotlib_version_info != (0,98,5,3) and \
-        matplotlib_version_info != (0,98,5,2):
-        print "This code was only tested with Matplotlib-0.98.5.2 and \
-              Matplotlib-0.98.5.3"
+
+    if matplotlib_version_info != (1,1,0):
+        print "This code was only tested with Matplotlib-1.1.0"
 
     #get QIIME directory
     qiime_dir=get_qiime_project_dir()
