@@ -13,7 +13,7 @@ __author__ = "Greg Caporaso"
 __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Greg Caporaso","Jesse Stombaugh"]
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 __status__ = "Release"
@@ -93,7 +93,7 @@ def write_poller_files(polled_dir):
     
     return check_run_complete_fp, process_run_results_fp, clean_up_fp
 
-if __name__ == "__main__":
+def main():
     option_parser, opts, args = parse_command_line_parameters(**script_info)
     poller_fp = opts.poller_fp
     python_exe_fp = opts.python_exe_fp
@@ -126,6 +126,10 @@ if __name__ == "__main__":
           clean_up_fp)
         print 'Polling command:\n %s' % command
         system(command)
+
+
+if __name__ == "__main__":
+    main()
           
           
           
\ No newline at end of file
