@@ -7,7 +7,7 @@ __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Jens Reeder","Dan Knights", "Antonio Gonzalez Pena",
     "Justin Kuczynski"]
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 __status__ = "Release"
@@ -124,11 +124,18 @@ class Qiime_config(TestCase):
          "$SEQ_LOOKUP_FILE variable is not set to an existing filepath.")
          
         self.assertTrue(app_path("SplitKeys.pl"),
-         "AmpliconNoise Scripts directory doesn't seem to be in $PATH."+\
+         "Couldn't find SplitKeys.pl. "+\
+         "Perhaps AmpliconNoise Scripts directory isn't in $PATH?"+\
          " See %s for help." % url)
          
+        self.assertTrue(app_path("FCluster"),
+         "Couldn't find FCluster. "+\
+         "Perhaps the AmpliconNoise bin directory isn't in $PATH?"+\
+         " See %s for help." % url)
+
         self.assertTrue(app_path("Perseus"),
-         "AmpliconNoise bin directory doesn't seem to be in $PATH."+\
+         "Couldn't find Perseus. "+\
+         "Perhaps the AmpliconNoise bin directory isn't in $PATH?"+\
          " See %s for help." % url)
         
     def test_pynast_template_alignment_fp(self):
@@ -274,8 +281,8 @@ class Qiime_config(TestCase):
 
     def test_python_supported_version(self):
         """python is in path and version is supported """
-        min_acceptable_version = (2,6,0)
-        min_unacceptable_version = (2,7,0)
+        min_acceptable_version = (2,7,1)
+        min_unacceptable_version = (2,7,2)
         command = 'python --version'
         proc = Popen(command,shell=True,universal_newlines=True,\
                          stdout=PIPE,stderr=STDOUT)
@@ -284,51 +291,52 @@ class Qiime_config(TestCase):
         try:
             version = tuple(map(int,version_string.split('.')))
             if len(version) == 2:
-                version = tuple(version[0],version[1],0)
-            pass_test = (version >= min_acceptable_version and version < min_unacceptable_version)
+                version = (version[0],version[1],0)
+            pass_test = (version >= min_acceptable_version and version <= min_unacceptable_version)
         except ValueError:
             pass_test = False
             version_string = stdout
         self.assertTrue(pass_test,\
-         "Unsupported python version. Must be >= %s and < %s , but running %s." \
+         "Unsupported python version. Must be >= %s and <= %s , but running %s." \
          % ('.'.join(map(str,min_acceptable_version)),
             '.'.join(map(str,min_unacceptable_version)),
             version_string))
 
     def test_numpy_suported_version(self):
         """numpy version is supported """
-        min_acceptable_version = (1,3,0)
+        min_acceptable_version = (1,5,1)
         min_unacceptable_version = (1,5,1)
         try:
             from numpy import __version__ as numpy_lib_version
             version = tuple(map(int,numpy_lib_version.split('.')))
-            pass_test = (version >= min_acceptable_version and version < min_unacceptable_version)
+            pass_test = (version >= min_acceptable_version and version <= min_unacceptable_version)
             version_string = str(numpy_lib_version)
         except ImportError:
             pass_test = False
             version_string = "Not installed"
         self.assertTrue(pass_test,\
-         "Unsupported numpy version. Must be >= %s and < %s , but running %s." \
+         "Unsupported numpy version. Must be >= %s and <= %s , but running %s." \
          % ('.'.join(map(str,min_acceptable_version)),
             '.'.join(map(str,min_unacceptable_version)),
             version_string))
 
     def test_matplotlib_suported_version(self):
         """maptplotlib version is supported """
-        min_acceptable_version = (0,98,5,3)
-        min_unacceptable_version = (0,98,5,4)
+        #min_acceptable_version = (1,1,0)
+        #min_unacceptable_version = (1,1,0)
+        matplotlib_acceptable_version = (1,1,0)
         try:
             from matplotlib import __version__ as matplotlib_lib_version
             version = tuple(map(int,matplotlib_lib_version.split('.')))
-            pass_test = (version >= min_acceptable_version and version < min_unacceptable_version)
+            pass_test = (version == matplotlib_acceptable_version)
             version_string = str(matplotlib_lib_version)
         except ImportError:
             pass_test = False
             version_string = "Not installed"
         self.assertTrue(pass_test,\
-         "Unsupported matplotlib version. Must be >= %s and < %s , but running %s." \
-         % ('.'.join(map(str,min_acceptable_version)),
-            '.'.join(map(str,min_unacceptable_version)),
+         "Unsupported matplotlib version. Must be >= %s and <= %s , but running %s." \
+         % ('.'.join(map(str,matplotlib_acceptable_version)),
+            '.'.join(map(str,matplotlib_acceptable_version)),
             version_string))
             
     def test_pynast_suported_version(self):
@@ -438,7 +446,7 @@ class Qiime_config(TestCase):
         
     def test_muscle_supported_version(self):
         """muscle is in path and version is supported """
-        acceptable_version = (3,6)
+        acceptable_version = (3,8,31)
         self.assertTrue(app_path('muscle'),
          "muscle not found. This may or may not be a problem depending on "+\
          "which components of QIIME you plan to use.")
@@ -583,7 +591,7 @@ def test_qiime_config_variable(variable, qiime_config, test,
     test.assertTrue(access(fp, access_var),
                     "%s is not %s: %s" % (variable, modes[access_var], fp))
 
-if __name__ == "__main__":
+def main():
     option_parser, opts, args = parse_command_line_parameters(**script_info)
 
     qiime_config = load_qiime_config()
@@ -629,3 +637,6 @@ if __name__ == "__main__":
     if (opts.test):
         print "\n\nrunning checks:\n"
         test_main(argv=["","-v"])
+
+if __name__ == "__main__":
+    main()
