@@ -4,9 +4,9 @@ from __future__ import division
 
 __author__ = "Greg Caporaso"
 __copyright__ = "Copyright 2011, The QIIME Project"
-__credits__ = ["Greg Caporaso","Justin Kuczynski"]
+__credits__ = ["Greg Caporaso","Justin Kuczynski","Jose Carlos Clemente Litran"]
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 __status__ = "Release"
@@ -23,7 +23,7 @@ from qiime.transform_coordinate_matrices import procrustes_monte_carlo,\
 
 script_info={}
 script_info['brief_description']="""Transform 2 coordinate matrices"""
-script_info['script_description']="""This script transformms 2 coordinate matrices (e.g., the output of principal_coordinates.py) using procrustes analysis to minimize the distances between corresponding points. Monte Carlo simulations can additionally be performed (-r random trials are run) to estimate the probability of seeing an M^2 value as extreme as the actual M^2."""
+script_info['script_description']="""This script transforms 2 coordinate matrices (e.g., the output of principal_coordinates.py) using procrustes analysis to minimize the distances between corresponding points. Monte Carlo simulations can additionally be performed (-r random trials are run) to estimate the probability of seeing an M^2 value as extreme as the actual M^2."""
 script_info['script_usage']=[]
 script_info['script_usage'].append(("Generate monte carlo p-values","","""%prog -r 1000 -i weighted_unifrac_coords.txt,unweighted_unifrac_coords.txt""",))
   
@@ -31,22 +31,23 @@ script_info['script_usage'].append(("Write the transformed procrustes matrices t
 
 script_info['output_description']="""Two transformed coordinate matrices corresponding to the two input coordinate matrices, and (if -r was specified) a text file summarizing the results of the Monte Carlo simulations."""
 script_info['required_options']=[\
- make_option('-i','--input_fps',help='comma-separated input files'),\
- make_option('-o','--output_dir',help='the output directory'),\
+ make_option('-i','--input_fps',type='existing_filepaths',help='comma-separated input files'),\
+ make_option('-o','--output_dir',type='new_dirpath',help='the output directory'),\
 ]
 script_info['optional_options']=[\
- make_option('-r','--random_trials',type='int',\
-    help='Number of random permutations of matrix2 to perform. '+\
-    ' [default: (no Monte Carlo analysis performed)]',default=None),\
- make_option('-d','--num_dimensions',type='int',\
-    help='Number of dimensions to include in output matrices'+\
-    ' [default: Consider all dimensions]',default=None),\
- make_option('-s','--sample_id_map_fp',\
-    help='Map of original sample ids to new sample ids [default: %default]',\
-    default=None),\
- make_option('--store_trial_details',\
-    help='Store PC matrices for individual trials [default: %default]',\
-    default=False,action='store_true'),\
+ make_option('-r','--random_trials',type='int',
+    help='Number of random permutations of matrix2 to perform. '+
+    ' [default: (no Monte Carlo analysis performed)]',default=None),
+ make_option('-d','--num_dimensions',type='int',default=3,
+    help='Number of dimensions to include in output matrices'+
+    ' [default: %default]'),
+ make_option('-s','--sample_id_map_fp',
+    type='existing_filepath',
+    help='Map of original sample ids to new sample ids [default: %default]',
+    default=None),
+ make_option('--store_trial_details',
+    help='Store PC matrices for individual trials [default: %default]',
+    default=False,action='store_true'),
 ]
 
 script_info['version'] = __version__
@@ -71,10 +72,9 @@ def main():
         trial_output_dir = '%s/trial_details/' % output_dir
     else:
         trial_output_dir = None
-    
-    input_fps = opts.input_fps.split(',')
-    input_fp1 = input_fps[0]
-    input_fp2 = input_fps[1]
+  
+    input_fp1 = opts.input_fps[0]
+    input_fp2 = opts.input_fps[1]
     input_fp1_dir, input_fn1 = split(input_fp1)
     input_fp1_basename, input_fp1_ext = splitext(input_fn1)
     input_fp2_dir, input_fn2 = split(input_fp2)
@@ -127,4 +127,4 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
