@@ -6,7 +6,7 @@ __author__ = "Antonio Gonzalez Pena"
 __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Antonio Gonzalez Pena"]
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Antonio Gonzalez Pena"
 __email__ = "antgonza@gmail.com"
 __status__ = "Release"
@@ -30,8 +30,10 @@ script_info['script_usage'] = [
 script_info['output_description']= ""
 script_info['required_options']=[
   make_option('-i', '--input_path',
+     type='existing_filepath',
      help='input path: TRFLP text file'),
   make_option('-o', '--output_path',
+     type='new_filepath',
      help="output file: OTU table"),
 ]
 script_info['optional_options']=[]
@@ -59,4 +61,4 @@ def main():
  
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
