@@ -6,7 +6,7 @@ __author__ = "Rob Knight"
 __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Rob Knight", "Kyle Bittinger"]
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Kyle Bittinger"
 __email__ = "kylebittinger@gmail.com"
 __status__ = "Release"
@@ -26,8 +26,10 @@ script_info['output_description']="""This script replaces the original sff files
 
 script_info['required_options'] = [
     make_option("-l", "--libdir", dest='libdir',
+        type='existing_path',
         help="The directory containing per-library sff files"),
     make_option("-m", "--input_map", dest='input_map',
+        type='existing_filepath',
         help="Path to the input mapping file describing the libraries"),
     ]
 
