@@ -1,13 +1,15 @@
 #!/usr/bin/env python
+from __future__ import division
 #unit tests for util.py
 
 from os import rmdir
 from os.path import split, abspath, dirname, exists, join
 from glob import glob
+from random import seed
 from cogent import Sequence
 from cogent.util.unit_test import TestCase, main
 from cogent.parse.fasta import MinimalFastaParser
-from qiime.util import get_tmp_filename
+from qiime.util import get_tmp_filename, load_qiime_config
 from cogent.util.misc import remove_files
 from cogent.cluster.procrustes import procrustes
 from cogent.app.formatdb import build_blast_db_from_fasta_file
@@ -28,7 +30,9 @@ from qiime.util import (make_safe_f, FunctionWithParams, qiime_blast_seqs,
     get_interesting_mapping_fields,inflate_denoiser_output,
     flowgram_id_to_seq_id_map, count_seqs, count_seqs_from_file,
     count_seqs_in_filepaths,get_split_libraries_fastq_params_and_file_types,
-    iseq_to_qseq_fields,get_top_fastq_two_lines,make_compatible_distance_matrices)
+    iseq_to_qseq_fields,get_top_fastq_two_lines,
+    make_compatible_distance_matrices,stderr,_chk_asarray,expand_otu_ids,
+    subsample_fasta,summarize_otu_sizes_from_otu_map)
 
 import numpy
 from numpy import array, asarray
@@ -40,7 +44,7 @@ __copyright__ = "Copyright 2011, The QIIME Project"
 __credits__ = ["Rob Knight", "Daniel McDonald","Greg Caporaso", 
                "Justin Kuczynski", "Jens Reeder", "Catherine Lozupone"] 
 __license__ = "GPL"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
 __status__ = "Release"
@@ -52,6 +56,7 @@ class TopLevelTests(TestCase):
         self.otu_table_f1 = otu_table_fake1.split('\n')
         self.otu_table_f2 = otu_table_fake2.split('\n')
         self.otu_table_f3 = otu_table_fake3.split('\n')
+        self.otu_table_f4 = otu_table_fake4.split('\n')
         self.otu_table_f1_no_tax = otu_table_fake1_no_tax.split('\n')
         self.otu_table_f2_no_tax = otu_table_fake2_no_tax.split('\n')
         self.otu_table_f3_no_tax = otu_table_fake3_no_tax.split('\n')
@@ -72,7 +77,25 @@ class TopLevelTests(TestCase):
         for dir in  self.dirs_to_remove:
             if exists(dir):
                 rmdir(dir)
-                
+
+    def test_expand_otu_ids(self):
+        """expand otu ids functions as expected """
+        otu_map = {'o1':['s1','s2'],
+                   'o2':['s3'],
+                   '3':   ['s4','s5']}
+        otus_to_expand = ['3','o1 test']
+        actual = expand_otu_ids(otu_map,otus_to_expand)
+        expected = ['s4','s5','s1','s2']
+        self.assertEqual(actual,expected)
+        
+        # ignore missing
+        otus_to_expand = ['3','o1 test','99']
+        actual = expand_otu_ids(otu_map,
+                                otus_to_expand,
+                                ignore_missing=True)
+        expected = ['s4','s5','s1','s2']
+        self.assertEqual(actual,expected)
+
     def test_median_absolute_deviation(self):
         """ median_absolute_deviation returns MAD and median """
         data = [0,0,0,0,0,0]
@@ -112,7 +135,15 @@ class TopLevelTests(TestCase):
         exp2 = exp + exp
         write_seqs_to_fasta(output_fp,seqs,'a')
         self.assertEqual(open(output_fp).read(),exp2)
-        
+    
+    def test_summarize_otu_sizes_from_otu_map(self):
+        """ summarize_otu_sizes_from_otu_map functions as expected """
+        otu_map_f = """O1	seq1
+o2	seq2	seq3	seq4	seq5
+o3	seq5
+o4	seq6	seq7""".split('\n')
+        expected = [(1,2),(2,1),(4,1)]
+        self.assertEqual(summarize_otu_sizes_from_otu_map(otu_map_f),expected)
     
     def test_split_fasta_on_sample_ids(self):
         """ split_fasta_on_sample_ids functions as expected 
@@ -314,21 +345,6 @@ class TopLevelTests(TestCase):
         # check that a file in qiime/support_files exists
         default_qiime_config_fp = join(support_files_dir,'qiime_config')
         self.assertTrue(exists(default_qiime_config_fp))
-        
-    def test_merge_otu_tables_error(self):
-        """merge_otu_tables throws error on overlapping sample IDs"""
-        # error on overlapping sample ids
-        self.assertRaises(AssertionError,\
-         merge_otu_tables,iter(self.otu_table_f1),iter(self.otu_table_f1))
-        
-    def test_merge_n_otu_tables_error(self):
-        """merge_n_otu_tables throws error on overlapping sample IDs"""
-        # error on overlapping sample ids
-        self.assertRaises(AssertionError,merge_n_otu_tables,
-                          [iter(self.otu_table_f1),
-                           iter(self.otu_table_f2),
-                           iter(self.otu_table_f3),
-                           iter(self.otu_table_f1)])
     
     def test_merge_otu_tables(self):
         """merge_otu_tables functions as expected"""
@@ -353,7 +369,52 @@ class TopLevelTests(TestCase):
         self.assertEqual(actual[1],exp_otu_ids)
         self.assertEqual(actual[2],exp_otu_table)
         self.assertEqual(actual[3],exp_lineages)
-    
+
+    def test_merge_otu_tables_w_overlapping_sample_ids(self):
+        """merge_otu_tables functions as expected w one overlapping sample id
+        """
+        otu_table_f1 = iter(self.otu_table_f1)
+        otu_table_f4 = iter(self.otu_table_f4)
+        exp_sample_ids = ['S1','S2','S3','S4']
+        exp_otu_ids = ['0','1','2','3','4','6']
+        exp_otu_table = array([[2,0,1,0],\
+                           [1,0,0,0],\
+                           [5,0,1,0],\
+                           [1,0,2,0],\
+                           [9,0,1,0],\
+                           [42,0,1,25]])
+        exp_lineages = [['Root','Bacteria'],\
+                    ['Root','Bacteria','Verrucomicrobia'],
+                    ['Root','Bacteria'],\
+                    ['Root','Bacteria','Acidobacteria'],\
+                    ['Root','Bacteria','Bacteroidetes'],\
+                    ['Root','Archaea']]
+        actual = merge_otu_tables(otu_table_f1,otu_table_f4)
+        self.assertEqual(actual[0],exp_sample_ids)
+        self.assertEqual(actual[1],exp_otu_ids)
+        self.assertEqual(actual[2],exp_otu_table)
+        self.assertEqual(actual[3],exp_lineages)
+
+    def test_merge_otu_tables_w_all_overlapping_sample_ids(self):
+        """merge_otu_tables functions as expected w all overlapping sample ids
+        """
+        otu_table_f1_1 = iter(self.otu_table_f1)
+        otu_table_f1_2 = iter(self.otu_table_f1)
+        exp_sample_ids = ['S1','S2']
+        exp_otu_ids = ['0','1','2']
+        exp_otu_table = array([[2,0],\
+                           [2,0],\
+                           [8,0]])
+        exp_lineages = [['Root','Bacteria'],\
+                    ['Root','Bacteria','Verrucomicrobia'],
+                    ['Root','Bacteria']]
+        actual = merge_otu_tables(otu_table_f1_1,otu_table_f1_2)
+        self.assertEqual(actual[0],exp_sample_ids)
+        self.assertEqual(actual[1],exp_otu_ids)
+        self.assertEqual(actual[2],exp_otu_table)
+        self.assertEqual(actual[3],exp_lineages)
+
+
     def test_merge_otu_tables_passed_in_tables(self):
         """merge_otu_tables functions with otu_table tuples"""
         otu_table1 = parse_otu_table(self.otu_table_f1)
@@ -515,7 +576,7 @@ class TopLevelTests(TestCase):
     def test_count_seqs(self):
         """ count_seqs functions as expected with fake seq_counter
         """
-        def seq_counter(filepath):
+        def seq_counter(filepath,parser=None):
             # Fake sequence counter to test count_seqs without
             # having to write files to disk (note don't need to
             # test actual sequence counters here as they're tested
@@ -577,7 +638,7 @@ class TopLevelTests(TestCase):
         fastq_files.append(barcode_fpath)
         self.files_to_remove.append(barcode_fpath)
 
-        exp='-i %s -b %s --rev_comp_barcode' % (seq_fpath,barcode_fpath)
+        exp='-i %s -b %s --rev_comp_mapping_barcodes' % (seq_fpath,barcode_fpath)
 
         obs=get_split_libraries_fastq_params_and_file_types(fastq_files,
                                                            map_fpath)
@@ -771,6 +832,14 @@ otu_table_fake3 = """#Full OTU Counts
 #OTU ID	samp7	Consensus Lineage
 6	1	Root;Archaea""" 
 
+otu_table_fake4 = """#Full OTU Counts
+#OTU ID	S3	S4	S1	Consensus Lineage
+0	1	0	1	Root;Bacteria
+3	2	0	1	Root;Bacteria;Acidobacteria
+4	1	0	9	Root;Bacteria;Bacteroidetes
+2	1	0	1	Root;Bacteria;Acidobacteria;Acidobacteria;Gp5
+6	1	25	42	Root;Archaea"""
+
 otu_table_fake1_no_tax = """#Full OTU Counts
 #OTU ID	S1	S2
 0	1	0
@@ -787,7 +856,7 @@ otu_table_fake2_no_tax = """#Full OTU Counts
 
 otu_table_fake3_no_tax = """#Full OTU Counts
 #OTU ID	samp7
-6	1""" 
+6	1"""
 
                                     
 class FunctionWithParamsTests(TestCase):
@@ -1185,7 +1254,22 @@ AAAAAAA
         self.assertEqual(iseq_to_qseq_fields(i,barcode_in_header=True,barcode_length=3),
                          expected)
 
- 
+
+    def test_stderr(self):
+        """stderr computes standard error for an array"""
+        
+        exp=array([0.57735026918962584,0.57735026918962584,
+                   0.57735026918962584,0.57735026918962584])
+        obs=stderr([[1,1,1,1],[2,2,2,2],[3,3,3,3]])
+        self.assertEqual(obs,exp)
+        
+    def test__chk_asarray(self):
+        """_chk_asarray converts list into a numpy array"""
+        
+        exp=(array([[1,1,1,1],[2,2,2,2],[3,3,3,3]]),0)
+        obs=_chk_asarray([[1,1,1,1],[2,2,2,2],[3,3,3,3]],0)
+        self.assertEqual(obs,exp)
+
 otu_map1 = fields_to_dict("""1:\ta\tb\tc
 2:\td
 3:\te\tf
@@ -1308,6 +1392,92 @@ fastq_mapping_fwd=["#SampleID\tBarcodeSequence\tLinkerPrimerSequence\tDescriptio
 "sample1\tGACGAGTCAGTC\tCCGGACTACHVGGGTWTCTAAT\tsample1",
 "sample2\tGTCTGACAGTTG\tCCGGACTACHVGGGTWTCTAAT\tsample2"]
 
+class SubSampleFastaTests(TestCase):
+    """ """
+    
+    def setUp(self):
+        """ """
+        self.expected_lines_50_perc = expected_lines_50_perc
+        self.expected_lines_20_perc = expected_lines_20_perc
+        
+        self.temp_dir = load_qiime_config()['temp_dir']
+        
+        self.fasta_lines = fasta_lines
+        self.fasta_filepath = get_tmp_filename(
+            prefix='subsample_test_', suffix='.fasta')
+        self.fasta_file = open(self.fasta_filepath, "w")
+        self.fasta_file.write(self.fasta_lines)
+        self.fasta_file.close()
+        
+        self.output_filepath = get_tmp_filename(prefix='subsample_output_',
+         suffix='.fasta')
+        
+        self._files_to_remove =\
+         [self.fasta_filepath]
+
+    def tearDown(self):
+        remove_files(self._files_to_remove)
+        
+    def test_subsample_fasta_50(self):
+        """ subsample_fasta correctly subsamples input fasta file """
+        
+        # fixed seed for consistent calls with random()
+        seed(128)
+        
+        subsample_fasta(self.fasta_filepath, self.output_filepath,
+         percent_subsample = 0.50)
+    
+        self._files_to_remove.append(self.output_filepath)
+         
+        actual_results =\
+         [line.strip() for line in open(self.output_filepath, "U")]
+        
+        self.assertEqual(actual_results, self.expected_lines_50_perc)
+
+    def test_subsample_fasta_20(self):
+        """ subsample_fasta correctly subsamples input fasta file """
+        
+        seed(12210)
+
+        subsample_fasta(self.fasta_filepath, self.output_filepath,
+         percent_subsample = 0.20)
+    
+        self._files_to_remove.append(self.output_filepath)
+         
+        actual_results =\
+         [line.strip() for line in open(self.output_filepath, "U")]
+        
+        self.assertEqual(actual_results, self.expected_lines_20_perc)
+        
+        
+        
+        
+    
+
+
+# Long strings of test data go here
+fasta_lines = """>seq1
+ACCAGCGGAGAC
+>seq2
+ACAGAGAGACCC
+>seq3
+ATTACCAGATTAC
+>seq4
+ACAGGAGACCGAGAAGA
+>seq5
+ACCAGAGACCGAGA
+"""
+
+expected_lines_50_perc = """>seq2
+ACAGAGAGACCC
+>seq4
+ACAGGAGACCGAGAAGA
+>seq5
+ACCAGAGACCGAGA""".split('\n')
+
+expected_lines_20_perc = """>seq4
+ACAGGAGACCGAGAAGA""".split('\n')
+
 
 #run unit tests if run from command-line
 if __name__ == '__main__':
